@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Codership Oy <info@codership.com>
+ * Copyright (C) 2010-2014 Codership Oy <info@codership.com>
  */
 
 #include "write_set.hpp"
@@ -11,8 +11,6 @@
 #include "gcs_action_source.hpp"
 #include "galera_service_thd.hpp"
 
-#include "gu_inttypes.hpp"
-
 #include <cstdlib>
 #include <check.h>
 
@@ -26,7 +24,7 @@ namespace
             GCache_setup(gu::Config& conf) : name_("write_set_test.gcache")
             {
                 conf.set("gcache.name", name_);
-                conf.set("gcache.size", "1M");
+                conf.set("gcache.size", "4M");
                 log_info << "conf for gcache: " << conf;
             }
 
@@ -106,17 +104,17 @@ START_TEST(test_key1)
     expected_size += gu::uleb128_size(expected_size);
 #endif
 
-    ck_assert_msg(key.serial_size() == expected_size, "%ld <-> %ld",
-                  key.serial_size(), expected_size);
+    fail_unless(key.serial_size() == expected_size, "%ld <-> %ld",
+                key.serial_size(), expected_size);
 
     KeyPartSequence kp(key.key_parts<KeyPartSequence>());
-    ck_assert(kp.size() == 4);
+    fail_unless(kp.size() == 4);
 
     gu::Buffer buf(key.serial_size());
     key.serialize(&buf[0], buf.size(), 0);
     KeyOS key2(1);
     key2.unserialize(&buf[0], buf.size(), 0);
-    ck_assert(key2 == key);
+    fail_unless(key2 == key);
 }
 END_TEST
 
@@ -158,17 +156,17 @@ START_TEST(test_key2)
     expected_size += gu::uleb128_size(expected_size);
 #endif
 
-    ck_assert_msg(key.serial_size() == expected_size, "%ld <-> %ld",
-                  key.serial_size(), expected_size);
+    fail_unless(key.serial_size() == expected_size, "%ld <-> %ld",
+                key.serial_size(), expected_size);
 
     KeyPartSequence kp(key.key_parts<KeyPartSequence>());
-    ck_assert(kp.size() == 4);
+    fail_unless(kp.size() == 4);
 
     gu::Buffer buf(key.serial_size());
     key.serialize(&buf[0], buf.size(), 0);
     KeyOS key2(2);
     key2.unserialize(&buf[0], buf.size(), 0);
-    ck_assert(key2 == key);
+    fail_unless(key2 == key);
 }
 END_TEST
 
@@ -216,14 +214,14 @@ START_TEST(test_write_set1)
         + 1 + 1 + 6 + 1 + 4 // key2
 #endif
         + 4 + 6; // rbr
-    ck_assert_msg(buf.size() == expected_size, "%zd <-> %zd <-> %zd",
-                  buf.size(), expected_size, ws.serial_size());
+    fail_unless(buf.size() == expected_size, "%zd <-> %zd <-> %zd",
+                buf.size(), expected_size, ws.serial_size());
 
 
     WriteSet ws2(0);
 
     size_t ret = ws2.unserialize(&buf[0], buf.size(), 0);
-    ck_assert(ret == expected_size);
+    fail_unless(ret == expected_size);
 
     WriteSet::KeySequence rks;
     ws.get_keys(rks);
@@ -231,9 +229,9 @@ START_TEST(test_write_set1)
     WriteSet::KeySequence rks2;
     ws.get_keys(rks2);
 
-    ck_assert(rks2 == rks);
+    fail_unless(rks2 == rks);
 
-    ck_assert(ws2.get_data() == ws.get_data());
+    fail_unless(ws2.get_data() == ws.get_data());
 
 }
 END_TEST
@@ -282,14 +280,14 @@ START_TEST(test_write_set2)
         + 1 + 1 + 6 + 1 + 4 // key2
 #endif
         + 4 + 6; // rbr
-    ck_assert_msg(buf.size() == expected_size, "%zd <-> %zd <-> %zd",
-                  buf.size(), expected_size, ws.serial_size());
+    fail_unless(buf.size() == expected_size, "%zd <-> %zd <-> %zd",
+                buf.size(), expected_size, ws.serial_size());
 
 
     WriteSet ws2(2);
 
     size_t ret = ws2.unserialize(&buf[0], buf.size(), 0);
-    ck_assert(ret == expected_size);
+    fail_unless(ret == expected_size);
 
     WriteSet::KeySequence rks;
     ws.get_keys(rks);
@@ -297,9 +295,9 @@ START_TEST(test_write_set2)
     WriteSet::KeySequence rks2;
     ws2.get_keys(rks2);
 
-    ck_assert(rks2 == rks);
+    fail_unless(rks2 == rks);
 
-    ck_assert(ws2.get_data() == ws.get_data());
+    fail_unless(ws2.get_data() == ws.get_data());
 
 }
 END_TEST
@@ -319,7 +317,7 @@ START_TEST(test_mapped_buffer)
     mb.resize(1 << 8);
     for (size_t i = 0; i < 16; ++i)
     {
-        ck_assert(mb[i] == static_cast<gu::byte_t>(i));
+        fail_unless(mb[i] == static_cast<gu::byte_t>(i));
     }
 
     for (size_t i = 16; i < (1 << 8); ++i)
@@ -331,7 +329,7 @@ START_TEST(test_mapped_buffer)
 
     for (size_t i = 0; i < (1 << 8); ++i)
     {
-        ck_assert(mb[i] == static_cast<gu::byte_t>(i));
+        fail_unless(mb[i] == static_cast<gu::byte_t>(i));
     }
 
     for (size_t i = 0; i < (1 << 20); ++i)
@@ -439,13 +437,12 @@ START_TEST(test_cert_hierarchical_v1)
 
         trx->set_received(0, wsi[i].local_seqno, wsi[i].global_seqno);
         Certification::TestResult result(cert.append_trx(trx));
-        ck_assert_msg(result == wsi[i].result,
-                      "wsi: %zu, g: %" PRId64 " r: %d er: %d",
-                      i, trx->global_seqno(), result, wsi[i].result);
-        ck_assert_msg(trx->depends_seqno() == wsi[i].expected_depends_seqno,
-                      "wsi: %zu g: %" PRId64 " ld: %" PRId64 " eld: %" PRId64,
-                      i, trx->global_seqno(), trx->depends_seqno(),
-                      wsi[i].expected_depends_seqno);
+        fail_unless(result == wsi[i].result, "g: %lld r: %d er: %d",
+                    trx->global_seqno(), result, wsi[i].result);
+        fail_unless(trx->depends_seqno() == wsi[i].expected_depends_seqno,
+                    "wsi: %zu g: %lld ld: %lld eld: %lld",
+                    i, trx->global_seqno(), trx->depends_seqno(),
+                    wsi[i].expected_depends_seqno);
         cert.set_trx_committed(trx);
         trx->unref();
     }
@@ -564,23 +561,19 @@ START_TEST(test_cert_hierarchical_v2)
 
         trx->set_received(0, wsi[i].local_seqno, wsi[i].global_seqno);
         Certification::TestResult result(cert.append_trx(trx));
-        ck_assert_msg(result == wsi[i].result, "g: %" PRId64 " res: %d exp: %d",
-                      trx->global_seqno(), result, wsi[i].result);
-        ck_assert_msg(trx->depends_seqno() == wsi[i].expected_depends_seqno,
-                      "wsi: %zu g: %" PRId64 " ld: %" PRId64 " eld: %" PRId64,
-                      i, trx->global_seqno(), trx->depends_seqno(),
-                      wsi[i].expected_depends_seqno);
+        fail_unless(result == wsi[i].result, "g: %lld res: %d exp: %d",
+                    trx->global_seqno(), result, wsi[i].result);
+        fail_unless(trx->depends_seqno() == wsi[i].expected_depends_seqno,
+                    "wsi: %zu g: %lld ld: %lld eld: %lld",
+                    i, trx->global_seqno(), trx->depends_seqno(),
+                    wsi[i].expected_depends_seqno);
         cert.set_trx_committed(trx);
         trx->unref();
     }
 }
 END_TEST
 
-// This test leaks memory and it is for trx protocol version 2
-// which is pre 25.3.5. Disabling this test for now with ASAN
-// build. The test should be either removed or fixed to work
-// with more recent protocol versions.
-#ifndef GALERA_WITH_ASAN
+
 START_TEST(test_trac_726)
 {
     log_info << "test_trac_726";
@@ -616,7 +609,7 @@ START_TEST(test_trac_726)
 
         trx->set_received(0, 1, 1);
         Certification::TestResult result(cert.append_trx(trx));
-        ck_assert(result == Certification::TEST_OK);
+        fail_unless(result == Certification::TEST_OK);
         cert.set_trx_committed(trx);
         trx->unref();
     }
@@ -642,13 +635,13 @@ START_TEST(test_trac_726)
 
         trx->set_received(0, 2, 2);
         Certification::TestResult result(cert.append_trx(trx));
-        ck_assert(result == Certification::TEST_FAILED);
+        fail_unless(result == Certification::TEST_FAILED);
         cert.set_trx_committed(trx);
         trx->unref();
     }
 }
 END_TEST
-#endif // GALERA_WITH_ASAN
+
 
 Suite* write_set_suite()
 {
@@ -682,15 +675,13 @@ Suite* write_set_suite()
 
     tc = tcase_create("test_cert_hierarchical_v2");
     tcase_add_test(tc, test_cert_hierarchical_v2);
-    tcase_set_timeout(tc, 120);
+    tcase_set_timeout(tc, 20);
     suite_add_tcase(s, tc);
 
-#ifndef GALERA_WITH_ASAN
     tc = tcase_create("test_trac_726");
     tcase_add_test(tc, test_trac_726);
     tcase_set_timeout(tc, 20);
     suite_add_tcase(s, tc);
-#endif
 
     return s;
 }
